@@ -1,7 +1,7 @@
 /*
  *  error.c
  *
- *  Copyright (c) 2006-2010 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2011 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -22,16 +22,13 @@
 
 /* TODO: needed for the libfetch stuff, unfortunately- we should kill it */
 #include <stdio.h>
-#include <limits.h>
-/* the following two are needed on BSD for libfetch */
-#if defined(HAVE_SYS_SYSLIMITS_H)
-#include <sys/syslimits.h> /* PATH_MAX */
-#endif
+/* the following two are needed for FreeBSD's libfetch */
+#include <limits.h> /* PATH_MAX */
 #if defined(HAVE_SYS_PARAM_H)
 #include <sys/param.h> /* MAXHOSTNAMELEN */
 #endif
 
-#if defined(INTERNAL_DOWNLOAD)
+#ifdef HAVE_LIBFETCH
 #include <fetch.h> /* fetchLastErrString */
 #endif
 
@@ -60,6 +57,8 @@ const char SYMEXPORT *alpm_strerror(int err)
 			return _("could not find or read directory");
 		case PM_ERR_WRONG_ARGS:
 			return _("wrong or NULL argument passed");
+		case PM_ERR_DISK_SPACE:
+			return _("not enough free disk space");
 		/* Interface */
 		case PM_ERR_HANDLE_NULL:
 			return _("library not initialized");
@@ -78,6 +77,8 @@ const char SYMEXPORT *alpm_strerror(int err)
 			return _("database already registered");
 		case PM_ERR_DB_NOT_FOUND:
 			return _("could not find database");
+		case PM_ERR_DB_VERSION:
+			return _("database is incorrect version");
 		case PM_ERR_DB_WRITE:
 			return _("could not update database");
 		case PM_ERR_DB_REMOVE:
@@ -136,6 +137,8 @@ const char SYMEXPORT *alpm_strerror(int err)
 		/* Miscellaenous */
 		case PM_ERR_RETRIEVE:
 			return _("failed to retrieve some files");
+		case PM_ERR_WRITE:
+			return _("failed to copy some file");
 		case PM_ERR_INVALID_REGEX:
 			return _("invalid regular expression");
 		/* Errors from external libraries- our own wrapper error */
@@ -145,7 +148,7 @@ const char SYMEXPORT *alpm_strerror(int err)
 			 * error string instead. */
 			return _("libarchive error");
 		case PM_ERR_LIBFETCH:
-#if defined(INTERNAL_DOWNLOAD)
+#ifdef HAVE_LIBFETCH
 			return fetchLastErrString;
 #else
 			/* obviously shouldn't get here... */
