@@ -1,7 +1,7 @@
 /*
  *  callback.h
  *
- *  Copyright (c) 2006-2010 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2011 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@ void cb_trans_conv(pmtransconv_t event, void *data1, void *data2,
 
 /* callback to handle display of transaction progress */
 void cb_trans_progress(pmtransprog_t event, const char *pkgname, int percent,
-                   int howmany, int remain);
+                   size_t howmany, size_t remain);
 
 /* callback to handle receipt of total download value */
 void cb_dl_total(off_t total);
@@ -41,7 +41,7 @@ void cb_dl_total(off_t total);
 void cb_dl_progress(const char *filename, off_t file_xfered, off_t file_total);
 
 /* callback to handle messages/notifications from pacman library */
-void cb_log(pmloglevel_t level, char *fmt, va_list args);
+void cb_log(pmloglevel_t level, const char *fmt, va_list args);
 
 #endif /* _PM_CALLBACK_H */
 
