@@ -101,7 +101,7 @@ int needs_root(void)
 }
 
 /* gets the current screen column width */
-int getcols(void)
+int getcols(int def)
 {
 #ifdef TIOCGSIZE
 	struct ttysize win;
@@ -114,7 +114,7 @@ int getcols(void)
 		return win.ws_col;
 	}
 #endif
-	return 0;
+	return def;
 }
 
 /* does the same thing as 'rm -rf' */
@@ -209,14 +209,13 @@ void indentprint(const char *str, int indent)
 {
 	wchar_t *wcstr;
 	const wchar_t *p;
-	int len, cidx, cols;
+	int len, cidx;
+	const int cols = getcols(0);
 
 	if(!str) {
 		return;
 	}
 
-	cols = getcols();
-
 	/* if we're not a tty, print without indenting */
 	if(cols == 0) {
 		printf("%s", str);
@@ -425,8 +424,6 @@ static int string_length(const char *s)
 
 void string_display(const char *title, const char *string)
 {
-	int len = 0;
-
 	if(title) {
 		printf("%s ", title);
 	}
@@ -434,7 +431,7 @@ void string_display(const char *title, const char *string)
 		printf(_("None"));
 	} else {
 		/* compute the length of title + a space */
-		len = string_length(title) + 1;
+		int len = string_length(title) + 1;
 		indentprint(string, len);
 	}
 	printf("\n");
@@ -443,7 +440,7 @@ void string_display(const char *title, const char *string)
 void list_display(const char *title, const alpm_list_t *list)
 {
 	const alpm_list_t *i;
-	int cols, len = 0;
+	int len = 0;
 
 	if(title) {
 		len = string_length(title) + 1;
@@ -453,11 +450,12 @@ void list_display(const char *title, const alpm_list_t *list)
 	if(!list) {
 		printf("%s\n", _("None"));
 	} else {
+		int cols;
+		const int maxcols = getcols(80);
 		for(i = list, cols = len; i; i = alpm_list_next(i)) {
 			char *str = alpm_list_getdata(i);
 			int s = string_length(str);
-			int maxcols = getcols();
-			if(maxcols > 0 && (cols + s + 2) >= maxcols) {
+			if(cols + s + 2 >= maxcols) {
 				int j;
 				cols = len;
 				printf("\n");
