@@ -16,6 +16,6 @@ self.addpkg2db("local", p)
 self.args = "-Qi %s" % p.name
 
 self.addrule("PACMAN_RETCODE=0")
-self.addrule("PACMAN_OUTPUT=%s" % p.name)
-self.addrule("PACMAN_OUTPUT=%s" % p.desc)
-self.addrule("PACMAN_OUTPUT=2007")
+self.addrule("PACMAN_OUTPUT=^Name.*%s" % p.name)
+self.addrule("PACMAN_OUTPUT=^Description.*%s" % p.desc)
+self.addrule("PACMAN_OUTPUT=^Build Date.*2007")
